import { select, csv, scaleLinear, scaleTime, max, extent,
        axisLeft, axisBottom, area, curveBasis,
       	format } from 'd3';

const svg=select('svg');
const height=parseFloat(svg.attr('height'));
const width=parseFloat(svg.attr('width'));

const render = data => {
  const title = 'World Population By Year';
  const xValue = d => d.year;
  const xAxisLabel='Year';
  const yValue = d => d.population;
  const yAxisLabel='Population';
  
  const margin ={top: 50, left:100, bottom:70, right:40};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  //console.log(xScale.domain());
  //console.log(xScale.range());
  
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)])
  	.range([innerHeight, 0])
  	.nice();
  //console.log(yScale.domain());
  //console.log(yScale.range());
  
	svg.append('text')
		.attr('class','title')
		.attr('y', margin.top)
  	.attr('x', width/2)
		.text(title);
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  const areaGenerator = new area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);

   g.append('path')
  	.attr('class', 'area-path')
  	.attr('d', areaGenerator(data));
  
  const yAxisTickFormat = number => 
  	format('.1s')(number)
  		.replace('G','B');
  
  //const yAxis = axisLeft(yScale);
  //yAxis(g.append('g'));
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(5)
  	.tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  
 	yAxisG.selectAll('.domain')
  		.remove();
 
  yAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y', -70)
  	.attr('x', -innerHeight/2)
  	.attr('fill', 'black')
    .text(yAxisLabel)
  	.attr('transform', `rotate(-90)`)
  	.attr('text-anchor','middle');
  
  //console.log(typeof(format('.3s')(1000000)));
  
  const xAxis = axisBottom(xScale)
  	.ticks(8)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain')
  	.remove();
  
  xAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y', 60)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
    .text(xAxisLabel);
  

};//end render

csv ('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv')
  .then(data=>{
		data.forEach(d=> {
    	d.year = new Date (d.year);
      d.population = +d.population;
  });
  //console.log(data);
  render(data);
});

